/****************************************************************************
** Meta object code from reading C++ file 'crystallographyextension.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/avogadro-1.2.0/libavogadro/src/extensions/crystallography/crystallographyextension.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'crystallographyextension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Avogadro__CrystallographyExtension[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      98,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: signature, parameters, type, tag, flags
      36,   35,   35,   35, 0x05,
      50,   35,   35,   35, 0x05,
      80,   35,   35,   35, 0x05,
     108,   35,   35,   35, 0x05,
     140,   35,   35,   35, 0x05,
     180,   35,   35,   35, 0x05,
     212,   35,   35,   35, 0x05,

 // slots: signature, parameters, type, tag, flags
     250,   35,   35,   35, 0x0a,
     268,   35,   35,   35, 0x0a,
     292,   35,   35,   35, 0x0a,
     306,   35,   35,   35, 0x0a,
     320,   35,   35,   35, 0x0a,
     334,   35,   35,   35, 0x0a,
     350,   35,   35,   35, 0x0a,
     367,   35,   35,   35, 0x0a,
     384,   35,   35,   35, 0x0a,
     401,   35,   35,   35, 0x0a,
     421,   35,   35,   35, 0x0a,
     440,  438,   35,   35, 0x0a,
     468,  466,   35,   35, 0x0a,
     494,  492,   35,   35, 0x0a,
     522,  492,   35,   35, 0x0a,
     558,  492,   35,   35, 0x0a,
     588,  586,   35,   35, 0x0a,
     629,   35,  622,   35, 0x0a,
     654,   35,  622,   35, 0x0a,
     685,  678,  622,   35, 0x0a,
     723,   35,  707,   35, 0x0a,
     770,   35,  754,   35, 0x0a,
     807,  801,  622,   35, 0x0a,
     828,  678,  622,   35, 0x0a,
     852,   35,  707,   35, 0x0a,
     885,   35,  754,   35, 0x0a,
     918,  801,  622,   35, 0x0a,
     964,   35,  941,   35, 0x0a,
     978,   35,  754,   35, 0x0a,
     998,   35,  754,   35, 0x0a,
    1039,   35,  754,   35, 0x0a,
    1086,   35, 1065,   35, 0x0a,
    1133,   35, 1110,   35, 0x0a,
    1159,   35, 1110,   35, 0x0a,
    1195,   35, 1184,   35, 0x0a,
    1233,   35, 1218,   35, 0x0a,
    1264,   35, 1256,   35, 0x0a,
    1285,   35,  622,   35, 0x0a,
    1301,   35,   35,   35, 0x0a,
    1340,   35,   35,   35, 0x0a,
    1378,   35,   35,   35, 0x0a,
    1437, 1425,   35,   35, 0x0a,
    1514, 1503,   35,   35, 0x0a,
    1586, 1579,   35,   35, 0x0a,
    1611,   35,   35,   35, 0x0a,
    1626,   35,   35,   35, 0x0a,
    1651,   35,   35,   35, 0x0a,
    1678, 1669,   35,   35, 0x0a,
    1709,   35,   35,   35, 0x0a,
    1724,   35,   35,   35, 0x0a,
    1744, 1741,  754,   35, 0x0a,
    1804, 1799,   35,   35, 0x0a,
    1834,   35, 1829,   35, 0x0a,
    1849,   35,   35,   35, 0x0a,
    1868,   35,   35,   35, 0x0a,
    1887,   35,   35,   35, 0x08,
    1905,   35,   35,   35, 0x08,
    1932,   35,   35,   35, 0x08,
    1954,   35,   35,   35, 0x08,
    1975,   35,   35,   35, 0x08,
    2015, 2006,   35,   35, 0x08,
    2045,   35,   35,   35, 0x28,
    2071,   35,   35,   35, 0x08,
    2095,   35,   35,   35, 0x08,
    2116,   35,   35,   35, 0x08,
    2139,   35,   35,   35, 0x08,
    2157,   35,   35,   35, 0x08,
    2178,   35,   35,   35, 0x08,
    2200,   35,   35,   35, 0x08,
    2225,   35,   35,   35, 0x08,
    2243,   35,   35,   35, 0x08,
    2266,   35,   35,   35, 0x08,
    2286,   35,   35,   35, 0x08,
    2309,   35,   35,   35, 0x08,
    2331,   35,   35,   35, 0x08,
    2359,   35,   35,   35, 0x08,
    2383,   35,   35,   35, 0x08,
    2412,   35,   35,   35, 0x08,
    2441,   35,   35,   35, 0x08,
    2466,   35,   35,   35, 0x08,
    2491,   35,   35,   35, 0x08,
    2510,   35,   35,   35, 0x08,
    2529,   35,   35,   35, 0x08,
    2556,   35,   35,   35, 0x08,
    2583,   35,   35,   35, 0x08,
    2602,   35,   35,   35, 0x08,
    2621,   35,   35,   35, 0x08,
    2646,   35,   35,   35, 0x08,
    2674,   35,   35,   35, 0x08,
    2695,   35,   35,   35, 0x08,
    2724,   35,   35,   35, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_Avogadro__CrystallographyExtension[] = {
    "Avogadro::CrystallographyExtension\0\0"
    "cellChanged()\0lengthUnitChanged(LengthUnit)\0"
    "angleUnitChanged(AngleUnit)\0"
    "coordsCartFracChanged(CartFrac)\0"
    "coordsPreserveCartFracChanged(CartFrac)\0"
    "matrixCartFracChanged(CartFrac)\0"
    "matrixVectorStyleChanged(VectorStyle)\0"
    "repaintMolecule()\0pushUndo(QUndoCommand*)\0"
    "showEditors()\0hideEditors()\0lockEditors()\0"
    "unlockEditors()\0refreshEditors()\0"
    "showProperties()\0hideProperties()\0"
    "refreshProperties()\0refreshActions()\0"
    "l\0setLengthUnit(LengthUnit)\0a\0"
    "setAngleUnit(AngleUnit)\0c\0"
    "setCoordsCartFrac(CartFrac)\0"
    "setCoordsPreserveCartFrac(CartFrac)\0"
    "setMatrixCartFrac(CartFrac)\0v\0"
    "setMatrixVectorStyle(VectorStyle)\0"
    "double\0lengthConversionFactor()\0"
    "angleConversionFactor()\0length\0"
    "convertLength(double)\0Eigen::Vector3d\0"
    "convertLength(Eigen::Vector3d)\0"
    "Eigen::Matrix3d\0convertLength(Eigen::Matrix3d)\0"
    "angle\0convertAngle(double)\0"
    "unconvertLength(double)\0"
    "unconvertLength(Eigen::Vector3d)\0"
    "unconvertLength(Eigen::Matrix3d)\0"
    "unconvertAngle(double)\0OpenBabel::OBUnitCell*\0"
    "currentCell()\0currentCellMatrix()\0"
    "currentCellMatrixInStandardOrientation()\0"
    "currentFractionalMatrix()\0"
    "CEUnitCellParameters\0currentCellParameters()\0"
    "QList<Eigen::Vector3d>\0currentFractionalCoords()\0"
    "currentCartesianCoords()\0QList<int>\0"
    "currentAtomicNumbers()\0QList<QString>\0"
    "currentAtomicSymbols()\0QString\0"
    "currentLatticeType()\0currentVolume()\0"
    "setCurrentCell(OpenBabel::OBUnitCell*)\0"
    "setCurrentCellMatrix(Eigen::Matrix3d)\0"
    "setCurrentCellParameters(CEUnitCellParameters)\0"
    "ids,fcoords\0"
    "setCurrentFractionalCoords(QList<QString>,QList<Eigen::Vector3d>)\0"
    "ids,coords\0"
    "setCurrentCartesianCoords(QList<QString>,QList<Eigen::Vector3d>)\0"
    "volume\0setCurrentVolume(double)\0"
    "fillUnitCell()\0reduceToAsymmetricUnit()\0"
    "wrapAtomsToCell()\0v1,v2,v3\0"
    "buildSuperCell(uint,uint,uint)\0"
    "rebuildBonds()\0orientStandard()\0in\0"
    "rotateCellMatrixToStandardOrientation(Eigen::Matrix3d)\0"
    "text\0showPasteDialog(QString)\0bool\0"
    "niggliReduce()\0showUnitCellAxes()\0"
    "hideUnitCellAxes()\0refreshEditors_()\0"
    "actionPerceiveSpacegroup()\0"
    "actionSetSpacegroup()\0actionFillUnitCell()\0"
    "actionReduceToAsymmetricUnit()\0skipUndo\0"
    "actionSymmetrizeCrystal(bool)\0"
    "actionSymmetrizeCrystal()\0"
    "actionPrimitiveReduce()\0actionNiggliReduce()\0"
    "actionToggleUnitCell()\0actionBuildSlab()\0"
    "actionPasteCrystal()\0actionToggleEditors()\0"
    "actionToggleProperties()\0actionWrapAtoms()\0"
    "actionTranslateAtoms()\0actionViewOptions()\0"
    "actionOrientStandard()\0actionScaleToVolume()\0"
    "actionUnitsLengthAngstrom()\0"
    "actionUnitsLengthBohr()\0"
    "actionUnitsLengthNanometer()\0"
    "actionUnitsLengthPicometer()\0"
    "actionUnitsAngleDegree()\0"
    "actionUnitsAngleRadian()\0actionCoordsCart()\0"
    "actionCoordsFrac()\0actionCoordsPreserveCart()\0"
    "actionCoordsPreserveFrac()\0"
    "actionMatrixCart()\0actionMatrixFrac()\0"
    "actionMatrixRowVectors()\0"
    "actionMatrixColumnVectors()\0"
    "actionSpgTolerance()\0cacheFractionalCoordinates()\0"
    "restoreFractionalCoordinates()\0"
};

void Avogadro::CrystallographyExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        CrystallographyExtension *_t = static_cast<CrystallographyExtension *>(_o);
        switch (_id) {
        case 0: _t->cellChanged(); break;
        case 1: _t->lengthUnitChanged((*reinterpret_cast< LengthUnit(*)>(_a[1]))); break;
        case 2: _t->angleUnitChanged((*reinterpret_cast< AngleUnit(*)>(_a[1]))); break;
        case 3: _t->coordsCartFracChanged((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 4: _t->coordsPreserveCartFracChanged((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 5: _t->matrixCartFracChanged((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 6: _t->matrixVectorStyleChanged((*reinterpret_cast< VectorStyle(*)>(_a[1]))); break;
        case 7: _t->repaintMolecule(); break;
        case 8: _t->pushUndo((*reinterpret_cast< QUndoCommand*(*)>(_a[1]))); break;
        case 9: _t->showEditors(); break;
        case 10: _t->hideEditors(); break;
        case 11: _t->lockEditors(); break;
        case 12: _t->unlockEditors(); break;
        case 13: _t->refreshEditors(); break;
        case 14: _t->showProperties(); break;
        case 15: _t->hideProperties(); break;
        case 16: _t->refreshProperties(); break;
        case 17: _t->refreshActions(); break;
        case 18: _t->setLengthUnit((*reinterpret_cast< LengthUnit(*)>(_a[1]))); break;
        case 19: _t->setAngleUnit((*reinterpret_cast< AngleUnit(*)>(_a[1]))); break;
        case 20: _t->setCoordsCartFrac((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 21: _t->setCoordsPreserveCartFrac((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 22: _t->setMatrixCartFrac((*reinterpret_cast< CartFrac(*)>(_a[1]))); break;
        case 23: _t->setMatrixVectorStyle((*reinterpret_cast< VectorStyle(*)>(_a[1]))); break;
        case 24: { double _r = _t->lengthConversionFactor();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 25: { double _r = _t->angleConversionFactor();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 26: { double _r = _t->convertLength((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 27: { Eigen::Vector3d _r = _t->convertLength((*reinterpret_cast< const Eigen::Vector3d(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Eigen::Vector3d*>(_a[0]) = _r; }  break;
        case 28: { Eigen::Matrix3d _r = _t->convertLength((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 29: { double _r = _t->convertAngle((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 30: { double _r = _t->unconvertLength((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 31: { Eigen::Vector3d _r = _t->unconvertLength((*reinterpret_cast< const Eigen::Vector3d(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Eigen::Vector3d*>(_a[0]) = _r; }  break;
        case 32: { Eigen::Matrix3d _r = _t->unconvertLength((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 33: { double _r = _t->unconvertAngle((*reinterpret_cast< double(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 34: { OpenBabel::OBUnitCell* _r = _t->currentCell();
            if (_a[0]) *reinterpret_cast< OpenBabel::OBUnitCell**>(_a[0]) = _r; }  break;
        case 35: { Eigen::Matrix3d _r = _t->currentCellMatrix();
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 36: { Eigen::Matrix3d _r = _t->currentCellMatrixInStandardOrientation();
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 37: { Eigen::Matrix3d _r = _t->currentFractionalMatrix();
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 38: { CEUnitCellParameters _r = _t->currentCellParameters();
            if (_a[0]) *reinterpret_cast< CEUnitCellParameters*>(_a[0]) = _r; }  break;
        case 39: { QList<Eigen::Vector3d> _r = _t->currentFractionalCoords();
            if (_a[0]) *reinterpret_cast< QList<Eigen::Vector3d>*>(_a[0]) = _r; }  break;
        case 40: { QList<Eigen::Vector3d> _r = _t->currentCartesianCoords();
            if (_a[0]) *reinterpret_cast< QList<Eigen::Vector3d>*>(_a[0]) = _r; }  break;
        case 41: { QList<int> _r = _t->currentAtomicNumbers();
            if (_a[0]) *reinterpret_cast< QList<int>*>(_a[0]) = _r; }  break;
        case 42: { QList<QString> _r = _t->currentAtomicSymbols();
            if (_a[0]) *reinterpret_cast< QList<QString>*>(_a[0]) = _r; }  break;
        case 43: { QString _r = _t->currentLatticeType();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 44: { double _r = _t->currentVolume();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = _r; }  break;
        case 45: _t->setCurrentCell((*reinterpret_cast< OpenBabel::OBUnitCell*(*)>(_a[1]))); break;
        case 46: _t->setCurrentCellMatrix((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1]))); break;
        case 47: _t->setCurrentCellParameters((*reinterpret_cast< const CEUnitCellParameters(*)>(_a[1]))); break;
        case 48: _t->setCurrentFractionalCoords((*reinterpret_cast< const QList<QString>(*)>(_a[1])),(*reinterpret_cast< const QList<Eigen::Vector3d>(*)>(_a[2]))); break;
        case 49: _t->setCurrentCartesianCoords((*reinterpret_cast< const QList<QString>(*)>(_a[1])),(*reinterpret_cast< const QList<Eigen::Vector3d>(*)>(_a[2]))); break;
        case 50: _t->setCurrentVolume((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 51: _t->fillUnitCell(); break;
        case 52: _t->reduceToAsymmetricUnit(); break;
        case 53: _t->wrapAtomsToCell(); break;
        case 54: _t->buildSuperCell((*reinterpret_cast< const uint(*)>(_a[1])),(*reinterpret_cast< const uint(*)>(_a[2])),(*reinterpret_cast< const uint(*)>(_a[3]))); break;
        case 55: _t->rebuildBonds(); break;
        case 56: _t->orientStandard(); break;
        case 57: { Eigen::Matrix3d _r = _t->rotateCellMatrixToStandardOrientation((*reinterpret_cast< const Eigen::Matrix3d(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Eigen::Matrix3d*>(_a[0]) = _r; }  break;
        case 58: _t->showPasteDialog((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 59: { bool _r = _t->niggliReduce();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 60: _t->showUnitCellAxes(); break;
        case 61: _t->hideUnitCellAxes(); break;
        case 62: _t->refreshEditors_(); break;
        case 63: _t->actionPerceiveSpacegroup(); break;
        case 64: _t->actionSetSpacegroup(); break;
        case 65: _t->actionFillUnitCell(); break;
        case 66: _t->actionReduceToAsymmetricUnit(); break;
        case 67: _t->actionSymmetrizeCrystal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 68: _t->actionSymmetrizeCrystal(); break;
        case 69: _t->actionPrimitiveReduce(); break;
        case 70: _t->actionNiggliReduce(); break;
        case 71: _t->actionToggleUnitCell(); break;
        case 72: _t->actionBuildSlab(); break;
        case 73: _t->actionPasteCrystal(); break;
        case 74: _t->actionToggleEditors(); break;
        case 75: _t->actionToggleProperties(); break;
        case 76: _t->actionWrapAtoms(); break;
        case 77: _t->actionTranslateAtoms(); break;
        case 78: _t->actionViewOptions(); break;
        case 79: _t->actionOrientStandard(); break;
        case 80: _t->actionScaleToVolume(); break;
        case 81: _t->actionUnitsLengthAngstrom(); break;
        case 82: _t->actionUnitsLengthBohr(); break;
        case 83: _t->actionUnitsLengthNanometer(); break;
        case 84: _t->actionUnitsLengthPicometer(); break;
        case 85: _t->actionUnitsAngleDegree(); break;
        case 86: _t->actionUnitsAngleRadian(); break;
        case 87: _t->actionCoordsCart(); break;
        case 88: _t->actionCoordsFrac(); break;
        case 89: _t->actionCoordsPreserveCart(); break;
        case 90: _t->actionCoordsPreserveFrac(); break;
        case 91: _t->actionMatrixCart(); break;
        case 92: _t->actionMatrixFrac(); break;
        case 93: _t->actionMatrixRowVectors(); break;
        case 94: _t->actionMatrixColumnVectors(); break;
        case 95: _t->actionSpgTolerance(); break;
        case 96: _t->cacheFractionalCoordinates(); break;
        case 97: _t->restoreFractionalCoordinates(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Avogadro::CrystallographyExtension::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Avogadro::CrystallographyExtension::staticMetaObject = {
    { &Extension::staticMetaObject, qt_meta_stringdata_Avogadro__CrystallographyExtension,
      qt_meta_data_Avogadro__CrystallographyExtension, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Avogadro::CrystallographyExtension::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Avogadro::CrystallographyExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Avogadro::CrystallographyExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Avogadro__CrystallographyExtension))
        return static_cast<void*>(const_cast< CrystallographyExtension*>(this));
    return Extension::qt_metacast(_clname);
}

int Avogadro::CrystallographyExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 98)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 98;
    }
    return _id;
}

// SIGNAL 0
void Avogadro::CrystallographyExtension::cellChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void Avogadro::CrystallographyExtension::lengthUnitChanged(LengthUnit _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Avogadro::CrystallographyExtension::angleUnitChanged(AngleUnit _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Avogadro::CrystallographyExtension::coordsCartFracChanged(CartFrac _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Avogadro::CrystallographyExtension::coordsPreserveCartFracChanged(CartFrac _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Avogadro::CrystallographyExtension::matrixCartFracChanged(CartFrac _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Avogadro::CrystallographyExtension::matrixVectorStyleChanged(VectorStyle _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
static const uint qt_meta_data_Avogadro__CrystallographyExtensionFactory[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

static const char qt_meta_stringdata_Avogadro__CrystallographyExtensionFactory[] = {
    "Avogadro::CrystallographyExtensionFactory\0"
};

void Avogadro::CrystallographyExtensionFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObjectExtraData Avogadro::CrystallographyExtensionFactory::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Avogadro::CrystallographyExtensionFactory::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Avogadro__CrystallographyExtensionFactory,
      qt_meta_data_Avogadro__CrystallographyExtensionFactory, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Avogadro::CrystallographyExtensionFactory::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Avogadro::CrystallographyExtensionFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Avogadro::CrystallographyExtensionFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Avogadro__CrystallographyExtensionFactory))
        return static_cast<void*>(const_cast< CrystallographyExtensionFactory*>(this));
    if (!strcmp(_clname, "PluginFactory"))
        return static_cast< PluginFactory*>(const_cast< CrystallographyExtensionFactory*>(this));
    if (!strcmp(_clname, "net.sourceforge.avogadro.pluginfactory/1.5"))
        return static_cast< Avogadro::PluginFactory*>(const_cast< CrystallographyExtensionFactory*>(this));
    return QObject::qt_metacast(_clname);
}

int Avogadro::CrystallographyExtensionFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
